@@ -1,4 +1,4 @@
-from typing import Any, TypedDict, Literal
+from typing import TypedDict, Literal
 
 from method.resource import Resource
 from method.configuration import Configuration
@@ -14,5 +14,5 @@ class HealthCheckResource(Resource):
     def __init__(self, config: Configuration):
         super(HealthCheckResource, self).__init__(config.add_path('ping'))
 
-    def get(self) -> PingResponse:
+    def retrieve(self) -> PingResponse:
         return super(HealthCheckResource, self)._get_raw()
