@@ -9,14 +9,18 @@ ReportTypesLiterals = Literal[
     'payments.created.previous',
     'payments.updated.current',
     'payments.updated.previous',
+    'payments.created.previous_day',
+    'payments.failed.previous_day',
     'ach.pull.upcoming',
     'ach.pull.previous',
     'ach.pull.nightly',
-    'ach.reversals.nightly'
+    'ach.reversals.nightly',
+    'entities.created.previous_day'
 ]
 
 
 ReportStatusesLiterals = Literal[
+    'processing',
     'completed'
 ]
 
@@ -40,7 +44,7 @@ class ReportResource(Resource):
     def __init__(self, config: Configuration):
         super(ReportResource, self).__init__(config.add_path('reports'))
 
-    def get(self, _id: str) -> Report:
+    def retrieve(self, _id: str) -> Report:
         return super(ReportResource, self)._get_with_id(_id)
 
     def create(self, opts: ReportCreateOpts, request_opts: Optional[RequestOpts] = None) -> Report:
